/*
   SPDX-FileCopyrightText: 2015-2026 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once

#include <PimCommon/TemplateListWidget>

namespace ThemeDefaultTemplate
{
[[nodiscard]] QList<PimCommon::defaultTemplate> defaultTemplates();
}
